@@ -18,7 +18,7 @@
 #' @param relock if TRUE allows to update the env.lock file
 #'   (type: logical, default: FALSE)
 #' @param check_repos_consistency if TRUE will prevent installing
-#'   packages built for another R ver. (type: logical, default: TRUE)
+#'   packages built for another R ver. (type: logical, default: TRUE if R is stable)
 #'
 #' @keywords internal
 #' @noRd
@@ -26,7 +26,7 @@
 install_prj_deps <- function(params,
                              vanilla_sups = FALSE,
                              relock = FALSE,
-                             check_repos_consistency = TRUE) {
+                             check_repos_consistency = is_r_stable()) {
   pkg_loginfo("Detecting repositories (for R %s)...", params$r_ver)
 
   repo_infos <- get_all_repo_infos(params) # from 53_repositories.R
@@ -137,6 +137,26 @@ resolve_prj_deps <- function(repo_infos, params, only_source = FALSE) {
   project_packages <- build_project_pkgslist(params$pkgs_path) # from 51_pkg_info.R
   prj_dep_vers <- vers.rm(prj_dep_vers, project_packages)
 
+  # if locked?
+  if (file.exists(params$lock_path)) {
+    # apply lock requirements
+    env_lock_vers <- get_lock_env_vers(params) # from 52_dependencies.R
+    env_lock_vers <- vers.rm(env_lock_vers, project_packages)
+    env_lock_vers <- vers.rm(env_lock_vers, # remove non required locks
+                             setdiff(vers.get_names(env_lock_vers), vers.get_names(prj_dep_vers)))
+
+    # if lock requirements introduce some unfesibles assume some
+    #  requirements added altered in packages itself. So do not try
+    #  enforce lock requirements for them. Leave the problem to be resolved
+    #  later: while handling relocking etc.
+    prj_dep_candidate <- vers.union(prj_dep_vers, env_lock_vers)
+    candidate_unfeasibles <- vers.get_unfeasibles(prj_dep_candidate)
+    if (length(candidate_unfeasibles) == 0) {
+      prj_dep_vers <- prj_dep_candidate
+    } else {
+      prj_dep_vers <- vers.union(prj_dep_vers, vers.rm(env_lock_vers, candidate_unfeasibles))
+    }
+  }
 
   pkg_loginfo("Resolving dependencies (for R %s)...", params$r_ver)
   avail_vers <- resolve_dependencies(prj_dep_vers, repo_infos = repo_infos, pkg_types = pkg_types)
@@ -233,8 +253,7 @@ install_support_pkgs <- function(avail_vers, sbox_dir, lib_dir, rver,
     return(vers.rm_acceptable(vers, installed))
   }
 
-  is_r_stable <- !grepl("unstable", R.version$status)
-  avail_vers <- remove_installed(avail_vers, is_r_stable)
+  avail_vers <- remove_installed(avail_vers, is_r_stable())
   if (vers.is_empty(avail_vers)) {
     pkg_logdebug("No support packages to install.")
     return(invisible())
@@ -289,7 +308,7 @@ install_dependencies <- function(avail_vers, lib_dir, rver,
   stopifnot(avail_vers$has_avails())
   stopifnot(is_nonempty_char1(lib_dir))
 
-  remove_installed <- function(vers, check_built_rver) {
+  remove_installed <- function(vers, check_built_rver, notify_on_update) {
     installed <- as.data.frame(utils::installed.packages(lib.loc = lib_dir),
                                stringsAsFactors = FALSE)[, c("Package", "Version", "Built")]
     if (any(check_built_rver)) {
@@ -298,12 +317,11 @@ install_dependencies <- function(avail_vers, lib_dir, rver,
 
     avails <- vers$get_avails()
     if (nrow(avails) != 0) {
-      missing <- merge(installed, avails, by = c("Package", "Version"))
-      missing <- installed[!installed$Package %in% missing$Package, ]
+      present <- merge(installed, avails, by = c("Package", "Version"))
+      missing <- installed[!(installed$Package %in% present$Package), ]
 
-      if (length(missing$Package) != 0) {
-        pkg_loginfo("The following packages are no longer available in the repository and will be updated: %s",
-                    missing$Package)
+      if (length(missing$Package) != 0 && notify_on_update) {
+        pkg_loginfo("Following installed packages will be updated: %s", missing$Package)
       }
 
       # remove deprecated packages from installed so they get updated
@@ -313,8 +331,7 @@ install_dependencies <- function(avail_vers, lib_dir, rver,
     return(vers.rm_acceptable(vers, installed))
   }
 
-  is_r_stable <- !grepl("unstable", R.version$status)
-  avail_vers <- remove_installed(avail_vers, is_r_stable)
+  avail_vers <- remove_installed(avail_vers, is_r_stable(), notify_on_update = TRUE)
   if (vers.is_empty(avail_vers)) {
     pkg_loginfo("No dependencies to install.")
     return(invisible())
@@ -343,7 +360,7 @@ install_dependencies <- function(avail_vers, lib_dir, rver,
               rver = rver,
               check_repos_consistency = check_repos_consistency)
 
-  avail_vers <- remove_installed(avail_vers, check_repos_consistency)
+  avail_vers <- remove_installed(avail_vers, check_repos_consistency, notify_on_update = FALSE)
   assert(vers.is_empty(avail_vers),
          "Failed to install some dependencies: %s", paste(vers.get_names(avail_vers), collapse = ", "))
   pkg_loginfo("All dependencies successfully installed.")
@@ -517,24 +534,14 @@ pkg_inst_order <- function(pkgs, db) {
 #' @keywords internal
 #'
 clean_prj_deps <- function(params) {
-  all_installed <- data.frame(utils::installed.packages(lib.loc = params$lib_path), stringsAsFactors = FALSE)
+  all_installed <- collect_installed_pkgs(params) # from 52_dependencies.R
+  installed <- all_installed$valid
 
-  is_rver_valid <- majmin_rver(all_installed$Built) == majmin_rver(params$r_ver)
-  installed <- all_installed[is_rver_valid, ]
+  required <- collect_prj_required_dep_names(params, installed) # from 53_dependencies.R
+  proj_pkgs <- build_project_pkgslist(params$pkgs_path) # from 51_pkg_info.R
 
-  deps <- collect_prj_direct_deps(params) # from 52_dependencies.R
-
-  # to satisfy collect_all_subseq_deps requirements
-  installed$Repository <- rep(params$lib_path, nrow(installed))
-  installed$File <- rep(NA, nrow(installed))
-
-  cr <- collect_all_subseq_deps(deps, all_pkgs = installed) # from 52_dependencies.R
-
-  proj_pkgs <- build_project_pkgslist(params$pkgs_path)
-
-  required <- c(cr$get_found_names(), proj_pkgs)
   to_clean <- c(setdiff(installed$Package, required), # non required
-                setdiff(all_installed[!is_rver_valid, "Package"], proj_pkgs))  # invalid
+                setdiff(all_installed$invalid[, "Package"], proj_pkgs))  # invalid
 
   if (!length(to_clean)) {
     pkg_loginfo("All installed packages are required by the project.")
