@@ -43,11 +43,18 @@ pkg_download <- function(avail_pkgs, dest_dir) {
     add = TRUE)
 
     build_result <- run_rscript(c("load(%s)",
-                                  "remote_paths <- download.packages(pkgs$Package, available = pkgs, %s)",
+                                  "remote_paths <- matrix(character(), 0L, 2L)",
+                                  paste0("for (p in pkgs$Package) ",
+                                         "tryCatch({",
+                                         "res <- download.packages(p, available = pkgs, %s); ",
+                                         "remote_paths <- rbind(remote_paths, res)}, ",
+                                         "warning = function(w) {}, ",
+                                         "error = function(e) {})"),
                                   "save(remote_paths, %s)"),
                                 rscript_arg("file", in_file),
                                 paste(common_args, collapse = ", "),
                                 rscript_arg("file", ou_file))
+
     if (!is.null(build_result)) {
       if (build_result == FALSE) {
         pkg_logwarn("Downloading aborted")
@@ -59,7 +66,6 @@ pkg_download <- function(avail_pkgs, dest_dir) {
 
     remote_paths <- NULL # just to prevent warning: set in load below
     load(ou_file)
-    # TODO: check if packages indeed download. Remove if not
 
     remote_paths <- as.data.frame(remote_paths, stringsAsFactors = FALSE)
     colnames(remote_paths) <- c("Package", "Path")
@@ -73,26 +79,33 @@ pkg_download <- function(avail_pkgs, dest_dir) {
     # check/build download cache
     dload_cache_dir <- get_cache_dir("dload_cache") # from 98_shell.R
     if (!is.null(dload_cache_dir)) {
-      cache_files <- file.path(dload_cache_dir,
-                               vapply(X = remote_pkgs$Repository,
-                                      FUN = function(repo) utils::URLencode(repo, TRUE),
-                                      FUN.VALUE = ""),
-                               remote_pkgs$File)
-      cache_exists <- file.exists(cache_files)
+      remote_pkgs$CacheFile <-
+        file.path(dload_cache_dir,
+                  vapply(X = remote_pkgs$Repository,
+                         FUN = function(repo) utils::URLencode(repo, TRUE),
+                         FUN.VALUE = ""),
+                  remote_pkgs$File)
 
+      cache_exists <- file.exists(remote_pkgs$CacheFile)
       if (!all(cache_exists)) {
         # Cache files which are not present in cache
-        remote_paths <- do_dload(remote_pkgs[!cache_exists, ])
+        to_dload_pkgs <- remote_pkgs[!cache_exists, ]
+        remote_paths <- do_dload(to_dload_pkgs)
+        dloaded_pkgs <- merge(remote_paths, remote_pkgs, by = "Package", all = FALSE)
 
         try({
           # cache them
           suppressWarnings({
-            lapply(X = unique(dirname(cache_files[!cache_exists])),
+            lapply(X = unique(dirname(dloaded_pkgs$CacheFile)),
                    FUN = function(dir_path) dir.create(dir_path, recursive = TRUE, showWarnings = FALSE))
-            file.copy(from = remote_paths$Path, to = cache_files[!cache_exists], overwrite = TRUE)
+            file.copy(from = dloaded_pkgs$Path, to = dloaded_pkgs$CacheFile, overwrite = TRUE)
           })
         },
         silent = TRUE)
+
+        dload_failed_pkgs <- setdiff(to_dload_pkgs$Package, dloaded_pkgs$Package)
+        assert(length(dload_failed_pkgs) == 0,
+               "Failed to download packages: %s", paste(dload_failed_pkgs, collapse = ", "))
       } else {
         # All files are cached: available locally
         remote_paths <- data.frame()
@@ -100,12 +113,17 @@ pkg_download <- function(avail_pkgs, dest_dir) {
 
       if (any(cache_exists)) {
         local_pkgs <- remote_pkgs[cache_exists, ]
-        local_pkgs$Repository <- path2local_url(dirname(cache_files[cache_exists])) # from 99_rpatches.R
+        local_pkgs$Repository <- path2local_url(dirname(local_pkgs$CacheFile)) # from 99_rpatches.R
+        local_pkgs$CacheFile <- NULL # ret rid of extra column
         pkg_logdebug(sprintf("Will use '%s' from cached %s", local_pkgs$Package, local_pkgs$File))
       }
     } else {
       # Caching is off: just download them
       remote_paths <- do_dload(remote_pkgs)
+
+      dload_failed_pkgs <- setdiff(remote_pkgs$Package, remote_paths$Package)
+      assert(length(dload_failed_pkgs) == 0,
+             "Failed to download packages: %s", paste(dload_failed_pkgs, collapse = ", "))
     }
 
     dloaded <- rbind(dloaded, remote_paths)
@@ -124,10 +142,6 @@ pkg_download <- function(avail_pkgs, dest_dir) {
     dloaded <- rbind(dloaded, local_paths[, c("Package", "Path")])
   }
 
-  assert(all(avail_pkgs$Package %in% dloaded$Package),
-         "Failed to download packages: %s",
-         paste(setdiff(avail_pkgs$Package, dloaded$Package), collapse = ", "))
-
   return(dloaded)
 }
 
@@ -202,11 +216,19 @@ pkg_build <- function(pkg_path, dest_dir, binary, rver, libpath, sboxpath, skip_
 
   if ("rcpp_attribs" %in% skip_build_steps) {
     pkg_loginfo("Skipping Rcpp attributes compilation")
-    rcpp_attribs_skip_cmd <- paste("assignInNamespace('compile_rcpp_attributes',",
-                                   " function(pkg) { cat('Skipping Rcpp::compileAttributes\\n' )},",
-                                   "'devtools')")
+    # if devtools version is below 2.0.0 we need to Skip Rcpp attributes inside devtools
+    # for devtools > 2.0.1 it uses pkgbuild package which does not build Rcpp attributes by defailt
+    rcpp_attribs_handle_cmd <- paste(
+      "if (compareVersion(as.character(packageVersion('devtools')), '2.0.0') < 0) {",
+      "  assignInNamespace('compile_rcpp_attributes',",
+      "    function(pkg) { cat('Skipping Rcpp::compileAttributes\\n' )},",
+      "    'devtools')",
+      "}")
   } else {
-    rcpp_attribs_skip_cmd <- c()
+    rcpp_attribs_handle_cmd <- paste(
+      "if (compareVersion(as.character(packageVersion('devtools')), '2.0.0') >= 0) {",
+      sprintf("pkgbuild:::compile_rcpp_attributes(%s)", rscript_arg("path", pkg_path)),
+      "}")
   }
 
   vign_cleanup <- NULL
@@ -224,8 +246,8 @@ pkg_build <- function(pkg_path, dest_dir, binary, rver, libpath, sboxpath, skip_
   if ("tests" %in% skip_build_steps) {
     pkg_loginfo("Skipping package testing")
   } else if (devtools::uses_testthat(pkg = pkg_path)) {
-    # it roughly builds package before testing, so skiping Rcpp here also required
-    test_res <- run_rscript(c(rcpp_attribs_skip_cmd,
+    # it roughly builds package before testing, so skiping Rcpp attribs handling here also required
+    test_res <- run_rscript(c(rcpp_attribs_handle_cmd,
                               "test_results <- devtools::test(%s)",
                               "if (!testthat:::all_passed(test_results)) { stop('Tests failed') }"),
                             rscript_arg("pkg", pkg_path),
@@ -247,9 +269,10 @@ pkg_build <- function(pkg_path, dest_dir, binary, rver, libpath, sboxpath, skip_
   on.exit(unlink(ou_file, force = TRUE), add = TRUE)
 
   bld_res <- run_rscript(c("library(devtools)",
+                           "library(rstudioapi)", # this is required for devtools >= 2.0.1
                            ".libPaths(%s)",
                            "setwd(%s)", # to prevent loading .Rprofile by R CMD
-                           rcpp_attribs_skip_cmd,
+                           rcpp_attribs_handle_cmd,
                            "ou_path <- build(%s, vignettes = FALSE)",
                            "save(ou_path, %s)"),
                          rscript_arg("new", libpath),
@@ -285,12 +308,29 @@ pkg_build <- function(pkg_path, dest_dir, binary, rver, libpath, sboxpath, skip_
 #' @param pkgs packages to remove  (type: character).
 #' @param lib_dir directory to reinstall packages in (type: character).
 #'
+#' @return logical vertor of same size as pkgs with FALSE on positions
+#'  which failed to remove.
+#'
 #' @keywords internal
 #' @noRd
 #'
 pkg_remove <- function(pkgs, lib_dir) {
-  void <- lapply(X = pkgs,
+  to_remove <- lapply(X = pkgs,
                  FUN = function(pkg) {
+                   dll_path <- get_package_dll_path(lib_dir, pkg)
+                   if (!is.null(dll_path)) {
+                     loaded_paths <- vapply(getLoadedDLLs(),
+                                            FUN = function(dl) dl[["path"]],
+                                            FUN.VALUE = "")
+                     if (dll_path %in% loaded_paths) {
+                       library.dynam.unload(pkg, file.path(lib_dir, pkg))
+                     }
+
+                     if (unlink(dll_path, force = TRUE) != 0) {
+                       return(FALSE)
+                     }
+                   }
+
                    search_item <- paste("package", pkg, sep = ":")
                    while (search_item %in% search()) {
                      attch_pkg_path <- rsuite_fullUnifiedPath(system.file(package = pkg))
@@ -301,13 +341,29 @@ pkg_remove <- function(pkgs, lib_dir) {
                        #  there is no point to detach it
                        break
                      }
+
                      detach(search_item, unload = TRUE, character.only = TRUE,
                             force = TRUE) # force even if dependent packages are loaded
                    }
+
+                   return(TRUE)
                  })
+  to_remove <- unlist(to_remove)
+
   installed <- utils::installed.packages(lib_dir)[, "Package"]
-  to_remove <- intersect(pkgs, installed)
-  try (expr = suppressMessages(utils::remove.packages(to_remove, lib = lib_dir)))
+  locked_pkgs <- intersect(pkgs[!to_remove], installed)
+
+  remove_pkgs <- intersect(pkgs[to_remove], installed)
+  try (expr = suppressMessages(utils::remove.packages(remove_pkgs, lib = lib_dir)))
+
+  still_installed <- utils::installed.packages(lib_dir)[, "Package"]
+  failed_pkgs <- c(locked_pkgs, intersect(remove_pkgs, still_installed))
+
+  if (length(failed_pkgs) > 0) {
+    pkg_logwarn("Could not remove installed package(s): %s", failed_pkgs)
+  }
+
+  return(!(pkgs %in% failed_pkgs))
 }
 
 
@@ -525,7 +581,7 @@ get_specific_args <- function(pkg_file, spec_desc) {
 #'
 #' Retrieves R version package is built for.
 #'
-#' @param lib_dir path there package is installed. (type: character)
+#' @param lib_dir path where package is installed. (type: character)
 #' @param pkg_name name of package to get information for. (type: character)
 #'
 #' @return R version number the packages is built for.
@@ -542,3 +598,27 @@ get_package_build_rver <- function(lib_dir, pkg_name) {
   pkg_rver <- installed[pkg_name == installed$Package, "Built"][1]
   return(pkg_rver)
 }
+
+
+#'
+#' Creates absolute path to package dll if package has one.
+#'
+#' @param lib_dir path where package is installed. (type: character)
+#' @param pkg_name name of package to get information for. (type: character)
+#'
+#' @return absolute path to package dll or NULL if it does not have internal dlls.
+#'
+#' @keywords internal
+#' @noRd
+#'
+get_package_dll_path <- function(lib_dir, pkg_name) {
+  dll_name <- paste0(pkg_name, .Platform$dynlib.ext)
+  lib_dir <- normalizePath(lib_dir, "/", TRUE)
+  dll_path <- ifelse(nzchar(.Platform$r_arch),
+                     file.path(lib_dir, pkg_name, "libs", .Platform$r_arch, dll_name),
+                     file.path(lib_dir, pkg_name, "libs", dll_name))
+  if (!file.exists(dll_path)) {
+    return(NULL)
+  }
+  return(dll_path)
+}
